==> metanetx-sdk-4.1.1.tar.gz: metanetx-sdk-4.1.1/src/metanetx_sdk/cli/etl.py <==
# Copyright (c) 2019, Moritz E. Beber.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Provide MetaNetX table processing commands."""


import logging
from pathlib import Path

import click

from .. import api, extract, transform
from ..model import TableConfigurationModel


logger = logging.getLogger(__name__)


@click.group()
@click.help_option("--help", "-h")
def etl():
    """Subcommand for processing MetaNetX tables."""
    pass


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def chem_depr(filename, output):
    """
    Extract and transform a table with deprecated chemical identifiers.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing deprecated chemical identifiers.")
    config = TableConfigurationModel.load()
    logger.info("Extracting...")
    deprecated = extract.extract_table(
        Path(filename), config.chem_depr.columns, config.chem_depr.skip
    )
    logger.info("Transforming...")
    logger.info("Loading...")
    deprecated.to_csv(Path(output), **api.OUTPUT_OPTIONS)
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def chem_prop(filename, output):
    """
    Extract and transform a chemical properties table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing chemical properties.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_prop,
        mapping,
        transform.transform_chemical_properties,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def chem_xref(filename, output):
    """
    Extract and transform a chemical cross-references table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing chemical cross-references.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_xref,
        mapping,
        transform.transform_chemical_cross_references,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def comp_depr(filename, output):
    """
    Extract and transform a table with deprecated compartment identifiers.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing deprecated compartment identifiers.")
    config = TableConfigurationModel.load()
    logger.info("Extracting...")
    deprecated = extract.extract_table(
        Path(filename), config.comp_depr.columns, config.comp_depr.skip
    )
    logger.info("Transforming...")
    logger.info("Loading...")
    deprecated.to_csv(Path(output), **api.OUTPUT_OPTIONS)
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def comp_prop(filename, output):
    """
    Extract and transform a compartment properties table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing compartment properties.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_compartment_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.comp_prop,
        mapping,
        transform.transform_compartment_properties,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def comp_xref(filename, output):
    """
    Extract and transform a compartment cross-references table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing compartment cross-references.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_compartment_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.comp_xref,
        mapping,
        transform.transform_compartment_cross_references,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def reac_depr(filename, output):
    """
    Extract and transform a table with deprecated reaction identifiers.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing deprecated compartment identifiers.")
    config = TableConfigurationModel.load()
    logger.info("Extracting...")
    deprecated = extract.extract_table(
        Path(filename), config.reac_depr.columns, config.reac_depr.skip
    )
    logger.info("Transforming...")
    logger.info("Loading...")
    deprecated.to_csv(Path(output), **api.OUTPUT_OPTIONS)
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def reac_prop(filename, output):
    """
    Extract and transform a reaction properties table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing reaction properties.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_reaction_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.reac_prop,
        mapping,
        transform.transform_reaction_properties,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def reac_xref(filename, output):
    """
    Extract and transform a reaction cross-references table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing reaction cross-references.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_reaction_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.reac_xref,
        mapping,
        transform.transform_reaction_cross_references,
    )
    logger.info("Complete.")

==> metanetx-sdk-4.2.0.tar.gz: metanetx-sdk-4.2.0/src/metanetx_sdk/cli/etl.py <==
# Copyright (c) 2019, Moritz E. Beber.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Provide MetaNetX table processing commands."""


import logging
from pathlib import Path

import click

from .. import api, extract, transform
from ..model import TableConfigurationModel


logger = logging.getLogger(__name__)


@click.group()
@click.help_option("--help", "-h")
def etl():
    """Subcommand for processing MetaNetX tables."""
    pass


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def chem_prop(filename, output):
    """
    Extract and transform a chemical properties table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing chemical properties.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_prop,
        mapping,
        transform.transform_chemical_properties,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def chem_xref(filename, output):
    """
    Extract and transform a chemical cross-references table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing chemical cross-references.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_xref,
        mapping,
        transform.transform_chemical_cross_references,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def chem_depr(filename, output):
    """
    Extract and transform deprecated MetaNetX chemical identifiers.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing deprecated chemical identifiers.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_depr,
        mapping,
        transform.transform_deprecated_identifiers,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def comp_prop(filename, output):
    """
    Extract and transform a compartment properties table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing compartment properties.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_compartment_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.comp_prop,
        mapping,
        transform.transform_compartment_properties,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def comp_xref(filename, output):
    """
    Extract and transform a compartment cross-references table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing compartment cross-references.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_compartment_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.comp_xref,
        mapping,
        transform.transform_compartment_cross_references,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def comp_depr(filename, output):
    """
    Extract and transform deprecated MetaNetX compartment identifiers.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing deprecated compartment identifiers.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_depr,
        mapping,
        transform.transform_deprecated_identifiers,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def reac_prop(filename, output):
    """
    Extract and transform a reaction properties table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing reaction properties.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_reaction_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.reac_prop,
        mapping,
        transform.transform_reaction_properties,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def reac_xref(filename, output):
    """
    Extract and transform a reaction cross-references table.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing reaction cross-references.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_reaction_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.reac_xref,
        mapping,
        transform.transform_reaction_cross_references,
    )
    logger.info("Complete.")


@etl.command()
@click.help_option("--help", "-h")
@click.argument(
    "filename",
    metavar="<INPUT FILE>",
    type=click.Path(exists=True, file_okay=True, dir_okay=False),
)
@click.argument(
    "output",
    metavar="<OUTPUT FILE>",
    type=click.Path(exists=False, file_okay=True, dir_okay=False),
)
def reac_depr(filename, output):
    """
    Extract and transform deprecated MetaNetX reaction identifiers.

    INPUT FILE is the path to the raw MetaNetX source table.

    OUTPUT FILE is the path for the transformed table output.

    """
    logger.info("Processing deprecated reaction identifiers.")
    config = TableConfigurationModel.load()
    mapping = extract.extract_chemical_prefix_mapping()
    api.etl_table(
        Path(filename),
        Path(output),
        config.chem_depr,
        mapping,
        transform.transform_deprecated_identifiers,
    )
    logger.info("Complete.")
